@@ -1,10 +1,9 @@
-
+from __future__ import with_statement
 import os
 from shutil import rmtree
 from urlparse import urlparse
 from uuid import uuid4
 
-from django.contrib.auth.models import User
 from django.contrib.auth.tokens import default_token_generator
 from django.contrib.contenttypes.models import ContentType
 from django.core import mail
@@ -37,6 +36,10 @@ from mezzanine.urls import PAGES_SLUG
 from mezzanine.utils.importing import import_dotted_path
 from mezzanine.utils.tests import copy_test_to_media, run_pyflakes_for_package
 from mezzanine.utils.tests import run_pep8_for_package
+from mezzanine.utils.models import get_user_model
+from mezzanine.core.managers import DisplayableManager
+
+User = get_user_model()
 
 
 class Tests(TestCase):
@@ -191,6 +194,69 @@ class Tests(TestCase):
         self.assertEqual(ascendants[0].id, secondary.id)
         self.assertEqual(ascendants[1].id, primary.id)
 
+    def test_set_parent(self):
+        old_parent, _ = RichTextPage.objects.get_or_create(title="Old parent")
+        new_parent, _ = RichTextPage.objects.get_or_create(title="New parent")
+        child, _ = RichTextPage.objects.get_or_create(title="Child",
+                                                      slug="kid")
+        self.assertTrue(child.parent is None)
+        self.assertTrue(child.slug == "kid")
+
+        child.set_parent(old_parent)
+        child.save()
+        self.assertEqual(child.parent_id, old_parent.id)
+        self.assertTrue(child.slug == "old-parent/kid")
+
+        child = RichTextPage.objects.get(id=child.id)
+        self.assertEqual(child.parent_id, old_parent.id)
+        self.assertTrue(child.slug == "old-parent/kid")
+
+        child.set_parent(new_parent)
+        child.save()
+        self.assertEqual(child.parent_id, new_parent.id)
+        self.assertTrue(child.slug == "new-parent/kid")
+
+        child = RichTextPage.objects.get(id=child.id)
+        self.assertEqual(child.parent_id, new_parent.id)
+        self.assertTrue(child.slug == "new-parent/kid")
+
+        child.set_parent(None)
+        child.save()
+        self.assertTrue(child.parent is None)
+        self.assertTrue(child.slug == "kid")
+
+        child = RichTextPage.objects.get(id=child.id)
+        self.assertTrue(child.parent is None)
+        self.assertTrue(child.slug == "kid")
+
+        # Assert that cycles are detected.
+        p1, _ = RichTextPage.objects.get_or_create(title="p1")
+        p2, _ = RichTextPage.objects.get_or_create(title="p2")
+        p2.set_parent(p1)
+        with self.assertRaises(AttributeError):
+            p1.set_parent(p1)
+        with self.assertRaises(AttributeError):
+            p1.set_parent(p2)
+        p2c = RichTextPage.objects.get(title="p2")
+        with self.assertRaises(AttributeError):
+            p1.set_parent(p2c)
+
+    def test_set_slug(self):
+        parent, _ = RichTextPage.objects.get_or_create(title="Parent",
+                                                       slug="parent")
+        child, _ = RichTextPage.objects.get_or_create(title="Child",
+                                                      slug="parent/child",
+                                                      parent_id=parent.id)
+        parent.set_slug("new-parent-slug")
+        parent.save()
+        self.assertTrue(parent.slug == "new-parent-slug")
+
+        parent = RichTextPage.objects.get(id=parent.id)
+        self.assertTrue(parent.slug == "new-parent-slug")
+
+        child = RichTextPage.objects.get(id=child.id)
+        self.assertTrue(child.slug == "new-parent-slug/child")
+
     def test_description(self):
         """
         Test generated description is text version of the first line
@@ -340,6 +406,41 @@ class Tests(TestCase):
         for page in pages:
             self.assertEquals(rendered.count(page.title), len(page.in_menus))
 
+    def test_page_menu_default(self):
+        """
+        Test that the default value for the ``in_menus`` field is used
+        and that it doesn't get forced to unicode.
+        """
+        old_menu_temp = settings.PAGE_MENU_TEMPLATES
+        old_menu_temp_def = settings.PAGE_MENU_TEMPLATES_DEFAULT
+        try:
+            # MenusField initializes choices and default during model
+            # loading, so we can't just override settings.
+            from mezzanine.pages.models import BasePage
+            from mezzanine.pages.fields import MenusField
+            settings.PAGE_MENU_TEMPLATES = ((8, 'a', 'a'), (9, 'b', 'b'))
+
+            settings.PAGE_MENU_TEMPLATES_DEFAULT = None
+
+            class P1(BasePage):
+                in_menus = MenusField(blank=True, null=True)
+            self.assertEqual(P1().in_menus[0], 8)
+
+            settings.PAGE_MENU_TEMPLATES_DEFAULT = tuple()
+
+            class P2(BasePage):
+                in_menus = MenusField(blank=True, null=True)
+            self.assertEqual(P2().in_menus, None)
+
+            settings.PAGE_MENU_TEMPLATES_DEFAULT = [9]
+
+            class P3(BasePage):
+                in_menus = MenusField(blank=True, null=True)
+            self.assertEqual(P3().in_menus[0], 9)
+        finally:
+            settings.PAGE_MENU_TEMPLATES = old_menu_temp
+            settings.PAGE_MENU_TEMPLATES_DEFAULT = old_menu_temp_def
+
     def test_keywords(self):
         """
         Test that the keywords_string field is correctly populated.
@@ -582,3 +683,12 @@ class Tests(TestCase):
         os.remove(os.path.join(settings.MEDIA_ROOT, image_name))
         os.remove(os.path.join(thumb_path))
         rmtree(os.path.join(os.path.dirname(thumb_path)))
+
+    def test_searchable_manager_search_fields(self):
+        """
+        Test that SearchableManager can get appropriate params.
+        """
+        manager = DisplayableManager()
+        self.assertFalse(manager._search_fields)
+        manager = DisplayableManager(search_fields={'foo': 10})
+        self.assertTrue(manager._search_fields)
