@@ -1,11 +1,17 @@
-
 from django.core.exceptions import ImproperlyConfigured
 from django.db.models import Model, Field
 
-from mezzanine.conf import settings
 from mezzanine.utils.importing import import_dotted_path
 
 
+try:
+    from django.contrib.auth import get_user_model
+except ImportError:
+    def get_user_model():
+        from django.contrib.auth.models import User
+        return User
+
+
 def base_concrete_model(abstract, instance):
     """
     Used in methods of abstract models to find the super-most concrete
@@ -51,6 +57,7 @@ def upload_to(field_path, default):
     handlers to be implemented on a per field basis defined by the
     ``UPLOAD_TO_HANDLERS`` setting.
     """
+    from mezzanine.conf import settings
     for k, v in settings.UPLOAD_TO_HANDLERS.items():
         if k.lower() == field_path.lower():
             return import_dotted_path(v)
@@ -71,6 +78,7 @@ class AdminThumbMixin(object):
             thumb = getattr(self, self.admin_thumb_field, None)
         if thumb is None:
             return ""
+        from mezzanine.conf import settings
         from mezzanine.core.templatetags.mezzanine_tags import thumbnail
         x, y = settings.ADMIN_THUMB_SIZE.split('x')
         thumb_url = thumbnail(thumb, x, y)
